# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2020-01-03 08:04
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0052_auto_20191213_1503'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userclassremoverecord',
            options={'ordering': ['-created_at'], 'permissions': (('view_user_class_remove_records', 'view_user_class_remove_records'),)},
        ),
    ]
