{% extends "bee_django_user/custom_base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block nav %}
{% endblock %}
{% block content %}
    {% include 'bee_django_user/messages.html' %}
    <div class="text-center"><h4>绑定账号</h4></div>

    <div>
        <form method="post">
            {% csrf_token %}
            {% bootstrap_form form %}
            {% bootstrap_button '绑定' %}
        </form>
    </div>

{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {

        });
    </script>
{% endblock %}